==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Nom du processus</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Ligne de commande</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Heure de début</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Lecture du disque</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Écriture sur le disque</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap </translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non activé</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Téléverser</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Disque</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lecture du disque</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Écriture sur le disque</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forcer l&apos;arrêt de l&apos;application</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Thème sombre</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Arrêt de l&apos;application</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>L&apos;arrêt de cette application peut causer des pertes de données.
Souhaitez-vous vraiment continuer ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Mode compacte</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non activé</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Réception</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Envoi</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Aucune réponse</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Terminer le processus</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>L&apos;arrêt de ce processus peut causer des pertes de données.
Souhaitez-vous vraiment continuer ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspendre le processus</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reprendre le processus</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Afficher l&apos;emplacement de l&apos;exécutable</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 applications et %3 processus sont en cours d&apos;exécution</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Écriture sur le disque</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lecture du disque</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Réception</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Envoi</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin Moniteur Système est un logiciel de surveillance du système intuitif et puissant. Il peut surveiller le processeur, la mémoire, le réseau, le disque dur et autres.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Moniteur système Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Moniteur système Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Environnement de Bureau Deepin - Service d’initialisation de processus</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Environnement de Bureau Deepin - Bureau</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Environnement de Bureau Deepin - Proxy polkit</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Environnement de Bureau Deepin - Lançeur</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Environnement de Bureau Deepin - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Environnement de Bureau Deepin - Affichage d&apos;écran</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Environnement de Bureau Deepin - Service</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Environnement de Bureau Deepin - Démon de session</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Environnement de Bureau Deepin - Processus d’initialisation du démon</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Démon gestionnaire de fichiers Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Environnement de Bureau Deepin - Service de verrouillage d&apos;écran</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Gestionnaire de Fenêtres Deepin</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Commutateur du gestionnaire de fenêtres Deepin</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Notification(s) Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agent d&apos;impression dans le Cloud Deepin</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Service menu Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Démon boutique Deepin</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Processus de fenêtre</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Processus DBus de fenêtre</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Processus du système de fichiers virtuels en mode utilisateur</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Processus de serveur Fuse du système de fichiers virtuels en mode utilisateur</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Processus d&apos;aide du client boutique Deepin</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Gestionnaire de Réseaux</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Service DBus de PolicyKit </translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Démon de service d&apos;échange de fichier</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Service X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Méthode d&apos;entrée Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Processus DBus de la méthode d&apos;entrée Fcitx</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Processus méthode d&apos;entrée Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Client local ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Service Son</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Service Impression</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Gestionnaire de luminosité d&apos;écran</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Gestionnaire de service système</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Gestionnaire de service système - Démon de gestion de périphériques</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Démon Disque</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Démon Compte</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Démon DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Processus événement de la souris</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Service DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Démon Gnome keyring</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Démon Bluetooth</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Démon Énergie</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Gestionnaire de périphérique modem</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Processus du système de plateau d&apos;impression</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Navigateur Chrome sandbox</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Démon de périphérique touchpad Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Partition d&apos;échange</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non activé</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Méthode d&apos;entrée Sogou</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Cliquez sur l&apos;application que vous souhaitez arrêter</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mes processus</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tous les processus</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Plateau</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Nom du processus</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Ligne de commande</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Heure de début</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forcer l&apos;arrêt de l&apos;application</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Thème sombre</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Arrêt de l&apos;application</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>L&apos;arrêt de cette application peut causer des pertes de données.
Souhaitez-vous vraiment continuer ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non activé</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Réception</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Envoi</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Aucune réponse</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Terminer le processus</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>L&apos;arrêt de ce processus peut causer des pertes de données.
Souhaitez-vous vraiment continuer ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspendre le processus</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reprendre le processus</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Afficher l&apos;emplacement de l&apos;exécutable</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 applications et %3 processus sont en cours d&apos;exécution</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Écriture sur le disque</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lecture du disque</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Réception</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Envoi</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin Moniteur Système est un logiciel de surveillance du système intuitif et puissant. Il peut surveiller le processeur, la mémoire, le réseau, le disque dur et autres.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Moniteur système Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Moniteur système Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Environnement de Bureau Deepin - Service d’initialisation de processus</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Environnement de Bureau Deepin - Bureau</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Environnement de Bureau Deepin - Proxy polkit</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Environnement de Bureau Deepin - Lançeur</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Environnement de Bureau Deepin - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Environnement de Bureau Deepin - Affichage d&apos;écran</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Environnement de Bureau Deepin - Service</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Environnement de Bureau Deepin - Démon de session</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Environnement de Bureau Deepin - Processus d’initialisation du démon</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Démon gestionnaire de fichiers Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Environnement de Bureau Deepin - Service de verrouillage d&apos;écran</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Gestionnaire de Fenêtres Deepin</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Commutateur du gestionnaire de fenêtres Deepin</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Notification Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agent d&apos;impression dans le Cloud Deepin</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Service menu Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Démon boutique Deepin</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Processus de fenêtre</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Processus DBus de fenêtre</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Processus du système de fichiers virtuels en mode utilisateur</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Processus de serveur Fuse du système de fichiers virtuels en mode utilisateur</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Processus d&apos;aide du client boutique Deepin</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Gestionnaire de Réseaux</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Service DBus de PolicyKit </translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Démon de service d&apos;échange de fichier</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Service X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Méthode d&apos;entrée Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Processus DBus de la méthode d&apos;entrée Fcitx</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Processus méthode d&apos;entrée Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Client local ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Service Son</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Service Impression</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Gestionnaire de luminosité d&apos;écran</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Gestionnaire de service système</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Gestionnaire de service système - Démon de gestion de périphériques</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Démon Disque</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Démon Compte</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Démon DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Processus événement de la souris</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Service DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Démon Gnome keyring</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Démon Bluetooth</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Démon Énergie</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Gestionnaire de périphérique modem</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Processus du système de plateau d&apos;impression</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Navigateur Chrome sandbox</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Démon de périphérique touchpad Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Partition d&apos;échange</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non activé</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Cliquez sur l&apos;application que vous souhaitez arrêter</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mes processus</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tous les processus</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
</TS>
